=begin
#Elastic Email REST API

#This API is based on the REST API architecture, allowing the user to easily manage their data with this resource-based approach.    Every API call is established on which specific request type (GET, POST, PUT, DELETE) will be used.    The API has a limit of 20 concurrent connections and a hard timeout of 600 seconds per request.    To start using this API, you will need your Access Token (available <a target=\"_blank\" href=\"https://elasticemail.com/account#/settings/new/manage-api\">here</a>). Remember to keep it safe. Required access levels are listed in the given request’s description.    This is the documentation for REST API. If you’d like to read our legacy documentation regarding Web API v2 click <a target=\"_blank\" href=\"https://api.elasticemail.com/public/help\">here</a>.    Downloadable library clients can be found in our Github repository <a target=\"_blank\" href=\"https://github.com/ElasticEmail?tab=repositories&q=%22rest+api%22+in%3Areadme\">here</a>

The version of the OpenAPI document: 4.0.0
Contact: support@elasticemail.com
Generated by: https://openapi-generator.tech
OpenAPI Generator version: 5.2.1

=end

require 'cgi'

module ElasticEmail
  class TemplatesApi
    attr_accessor :api_client

    def initialize(api_client = ApiClient.default)
      @api_client = api_client
    end
    # Delete Template
    # Delete template with the specified name. Required Access Level: ModifyTemplates
    # @param name [String] Name of template.
    # @param [Hash] opts the optional parameters
    # @return [nil]
    def templates_by_name_delete(name, opts = {})
      templates_by_name_delete_with_http_info(name, opts)
      nil
    end

    # Delete Template
    # Delete template with the specified name. Required Access Level: ModifyTemplates
    # @param name [String] Name of template.
    # @param [Hash] opts the optional parameters
    # @return [Array<(nil, Integer, Hash)>] nil, response status code and response headers
    def templates_by_name_delete_with_http_info(name, opts = {})
      if @api_client.config.debugging
        @api_client.config.logger.debug 'Calling API: TemplatesApi.templates_by_name_delete ...'
      end
      # verify the required parameter 'name' is set
      if @api_client.config.client_side_validation && name.nil?
        fail ArgumentError, "Missing the required parameter 'name' when calling TemplatesApi.templates_by_name_delete"
      end
      # resource path
      local_var_path = '/templates/{name}'.sub('{' + 'name' + '}', CGI.escape(name.to_s))

      # query parameters
      query_params = opts[:query_params] || {}

      # header parameters
      header_params = opts[:header_params] || {}

      # form parameters
      form_params = opts[:form_params] || {}

      # http body (model)
      post_body = opts[:debug_body]

      # return_type
      return_type = opts[:debug_return_type]

      # auth_names
      auth_names = opts[:debug_auth_names] || ['apikey']

      new_options = opts.merge(
        :operation => :"TemplatesApi.templates_by_name_delete",
        :header_params => header_params,
        :query_params => query_params,
        :form_params => form_params,
        :body => post_body,
        :auth_names => auth_names,
        :return_type => return_type
      )

      data, status_code, headers = @api_client.call_api(:DELETE, local_var_path, new_options)
      if @api_client.config.debugging
        @api_client.config.logger.debug "API called: TemplatesApi#templates_by_name_delete\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
      end
      return data, status_code, headers
    end

    # Load Template
    # Load detailed information of the specified template. Required Access Level: ViewTemplates
    # @param name [String] Name of template.
    # @param [Hash] opts the optional parameters
    # @return [Template]
    def templates_by_name_get(name, opts = {})
      data, _status_code, _headers = templates_by_name_get_with_http_info(name, opts)
      data
    end

    # Load Template
    # Load detailed information of the specified template. Required Access Level: ViewTemplates
    # @param name [String] Name of template.
    # @param [Hash] opts the optional parameters
    # @return [Array<(Template, Integer, Hash)>] Template data, response status code and response headers
    def templates_by_name_get_with_http_info(name, opts = {})
      if @api_client.config.debugging
        @api_client.config.logger.debug 'Calling API: TemplatesApi.templates_by_name_get ...'
      end
      # verify the required parameter 'name' is set
      if @api_client.config.client_side_validation && name.nil?
        fail ArgumentError, "Missing the required parameter 'name' when calling TemplatesApi.templates_by_name_get"
      end
      # resource path
      local_var_path = '/templates/{name}'.sub('{' + 'name' + '}', CGI.escape(name.to_s))

      # query parameters
      query_params = opts[:query_params] || {}

      # header parameters
      header_params = opts[:header_params] || {}
      # HTTP header 'Accept' (if needed)
      header_params['Accept'] = @api_client.select_header_accept(['application/json'])

      # form parameters
      form_params = opts[:form_params] || {}

      # http body (model)
      post_body = opts[:debug_body]

      # return_type
      return_type = opts[:debug_return_type] || 'Template'

      # auth_names
      auth_names = opts[:debug_auth_names] || ['apikey']

      new_options = opts.merge(
        :operation => :"TemplatesApi.templates_by_name_get",
        :header_params => header_params,
        :query_params => query_params,
        :form_params => form_params,
        :body => post_body,
        :auth_names => auth_names,
        :return_type => return_type
      )

      data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
      if @api_client.config.debugging
        @api_client.config.logger.debug "API called: TemplatesApi#templates_by_name_get\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
      end
      return data, status_code, headers
    end

    # Update Template
    # Update existing template, overwriting existing data. Required Access Level: ModifyTemplates
    # @param name [String] Name of template.
    # @param template_payload [TemplatePayload] 
    # @param [Hash] opts the optional parameters
    # @return [Template]
    def templates_by_name_put(name, template_payload, opts = {})
      data, _status_code, _headers = templates_by_name_put_with_http_info(name, template_payload, opts)
      data
    end

    # Update Template
    # Update existing template, overwriting existing data. Required Access Level: ModifyTemplates
    # @param name [String] Name of template.
    # @param template_payload [TemplatePayload] 
    # @param [Hash] opts the optional parameters
    # @return [Array<(Template, Integer, Hash)>] Template data, response status code and response headers
    def templates_by_name_put_with_http_info(name, template_payload, opts = {})
      if @api_client.config.debugging
        @api_client.config.logger.debug 'Calling API: TemplatesApi.templates_by_name_put ...'
      end
      # verify the required parameter 'name' is set
      if @api_client.config.client_side_validation && name.nil?
        fail ArgumentError, "Missing the required parameter 'name' when calling TemplatesApi.templates_by_name_put"
      end
      # verify the required parameter 'template_payload' is set
      if @api_client.config.client_side_validation && template_payload.nil?
        fail ArgumentError, "Missing the required parameter 'template_payload' when calling TemplatesApi.templates_by_name_put"
      end
      # resource path
      local_var_path = '/templates/{name}'.sub('{' + 'name' + '}', CGI.escape(name.to_s))

      # query parameters
      query_params = opts[:query_params] || {}

      # header parameters
      header_params = opts[:header_params] || {}
      # HTTP header 'Accept' (if needed)
      header_params['Accept'] = @api_client.select_header_accept(['application/json'])
      # HTTP header 'Content-Type'
      header_params['Content-Type'] = @api_client.select_header_content_type(['application/json'])

      # form parameters
      form_params = opts[:form_params] || {}

      # http body (model)
      post_body = opts[:debug_body] || @api_client.object_to_http_body(template_payload)

      # return_type
      return_type = opts[:debug_return_type] || 'Template'

      # auth_names
      auth_names = opts[:debug_auth_names] || ['apikey']

      new_options = opts.merge(
        :operation => :"TemplatesApi.templates_by_name_put",
        :header_params => header_params,
        :query_params => query_params,
        :form_params => form_params,
        :body => post_body,
        :auth_names => auth_names,
        :return_type => return_type
      )

      data, status_code, headers = @api_client.call_api(:PUT, local_var_path, new_options)
      if @api_client.config.debugging
        @api_client.config.logger.debug "API called: TemplatesApi#templates_by_name_put\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
      end
      return data, status_code, headers
    end

    # Load Templates
    # Returns a list of templates for the specified type. Required Access Level: ViewTemplates
    # @param scope_type [Array<TemplateScope>] Return templates with specified scope only
    # @param [Hash] opts the optional parameters
    # @option opts [Array<TemplateType>] :template_types Return templates with specified type only
    # @option opts [Integer] :limit Maximum number of returned items.
    # @option opts [Integer] :offset How many items should be returned ahead.
    # @return [Array<Template>]
    def templates_get(scope_type, opts = {})
      data, _status_code, _headers = templates_get_with_http_info(scope_type, opts)
      data
    end

    # Load Templates
    # Returns a list of templates for the specified type. Required Access Level: ViewTemplates
    # @param scope_type [Array<TemplateScope>] Return templates with specified scope only
    # @param [Hash] opts the optional parameters
    # @option opts [Array<TemplateType>] :template_types Return templates with specified type only
    # @option opts [Integer] :limit Maximum number of returned items.
    # @option opts [Integer] :offset How many items should be returned ahead.
    # @return [Array<(Array<Template>, Integer, Hash)>] Array<Template> data, response status code and response headers
    def templates_get_with_http_info(scope_type, opts = {})
      if @api_client.config.debugging
        @api_client.config.logger.debug 'Calling API: TemplatesApi.templates_get ...'
      end
      # verify the required parameter 'scope_type' is set
      if @api_client.config.client_side_validation && scope_type.nil?
        fail ArgumentError, "Missing the required parameter 'scope_type' when calling TemplatesApi.templates_get"
      end
      # resource path
      local_var_path = '/templates'

      # query parameters
      query_params = opts[:query_params] || {}
      query_params[:'scopeType'] = @api_client.build_collection_param(scope_type, :multi)
      query_params[:'templateTypes'] = @api_client.build_collection_param(opts[:'template_types'], :multi) if !opts[:'template_types'].nil?
      query_params[:'limit'] = opts[:'limit'] if !opts[:'limit'].nil?
      query_params[:'offset'] = opts[:'offset'] if !opts[:'offset'].nil?

      # header parameters
      header_params = opts[:header_params] || {}
      # HTTP header 'Accept' (if needed)
      header_params['Accept'] = @api_client.select_header_accept(['application/json'])

      # form parameters
      form_params = opts[:form_params] || {}

      # http body (model)
      post_body = opts[:debug_body]

      # return_type
      return_type = opts[:debug_return_type] || 'Array<Template>'

      # auth_names
      auth_names = opts[:debug_auth_names] || ['apikey']

      new_options = opts.merge(
        :operation => :"TemplatesApi.templates_get",
        :header_params => header_params,
        :query_params => query_params,
        :form_params => form_params,
        :body => post_body,
        :auth_names => auth_names,
        :return_type => return_type
      )

      data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
      if @api_client.config.debugging
        @api_client.config.logger.debug "API called: TemplatesApi#templates_get\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
      end
      return data, status_code, headers
    end

    # Add Template
    # Add a new Template. Required Access Level: ModifyTemplates
    # @param template_payload [TemplatePayload] 
    # @param [Hash] opts the optional parameters
    # @return [Template]
    def templates_post(template_payload, opts = {})
      data, _status_code, _headers = templates_post_with_http_info(template_payload, opts)
      data
    end

    # Add Template
    # Add a new Template. Required Access Level: ModifyTemplates
    # @param template_payload [TemplatePayload] 
    # @param [Hash] opts the optional parameters
    # @return [Array<(Template, Integer, Hash)>] Template data, response status code and response headers
    def templates_post_with_http_info(template_payload, opts = {})
      if @api_client.config.debugging
        @api_client.config.logger.debug 'Calling API: TemplatesApi.templates_post ...'
      end
      # verify the required parameter 'template_payload' is set
      if @api_client.config.client_side_validation && template_payload.nil?
        fail ArgumentError, "Missing the required parameter 'template_payload' when calling TemplatesApi.templates_post"
      end
      # resource path
      local_var_path = '/templates'

      # query parameters
      query_params = opts[:query_params] || {}

      # header parameters
      header_params = opts[:header_params] || {}
      # HTTP header 'Accept' (if needed)
      header_params['Accept'] = @api_client.select_header_accept(['application/json'])
      # HTTP header 'Content-Type'
      header_params['Content-Type'] = @api_client.select_header_content_type(['application/json'])

      # form parameters
      form_params = opts[:form_params] || {}

      # http body (model)
      post_body = opts[:debug_body] || @api_client.object_to_http_body(template_payload)

      # return_type
      return_type = opts[:debug_return_type] || 'Template'

      # auth_names
      auth_names = opts[:debug_auth_names] || ['apikey']

      new_options = opts.merge(
        :operation => :"TemplatesApi.templates_post",
        :header_params => header_params,
        :query_params => query_params,
        :form_params => form_params,
        :body => post_body,
        :auth_names => auth_names,
        :return_type => return_type
      )

      data, status_code, headers = @api_client.call_api(:POST, local_var_path, new_options)
      if @api_client.config.debugging
        @api_client.config.logger.debug "API called: TemplatesApi#templates_post\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
      end
      return data, status_code, headers
    end
  end
end
